local keql = LibStub("AceAddon-3.0"):GetAddon("keql")
local addon = keql
local Quixote = LibStub("LibQuixote-2.0")
local db, dbpc
local L = LibStub("AceLocale-3.0"):GetLocale("keql")

function addon:InitTooltip()
	db, dbpc = keql.db.profile, keql.dbpc.profile
	if Quixote then
		self:HookScript(GameTooltip, "OnTooltipSetUnit")
		self:HookScript(GameTooltip, "OnTooltipSetItem")
	end
	-- Init Tracker Tooltips
	
	QuestWatchFrame:SetScript("OnMouseDown", function() if not dbpc.minimized then addon:TrackerClick() end end)
	QuestWatchFrame:SetScript("OnUpdate", function() 
		if not MouseIsOver(QuestWatchFrame) and dbpc.tooltipset then
			ResetCursor()
			GameTooltip:FadeOut()
			dbpc.tooltipset = false
		end	
		if MouseIsOver(QuestWatchFrame) then 
			addon:TrackerTooltip() 
		end 
	end)	
end

function addon:OnTooltipSetUnit(tooltip, ...)
	local name = tooltip:GetUnit()
	local Color = {}
	local Color2 = {}
	--addon:Debug("OnTooltipSetUnit:"..tostring(name))
	if name and Quixote:IsQuestMob(name) then
		for _, uid in Quixote:IterateQuestsForMob(name) do
			local _, _, title, level, tag, _, _, group, daily = Quixote:GetQuestByUid(uid)
			local _, got, need = Quixote:GetQuestObjective(uid, name)
			if db.colors.QuestColorLevels then
				Color = GetDifficultyColor(level)
			else
				Color = db.colors.tooltipquest
			end
			if db.colors.objfade then
				Color2.r, Color2.g, Color2.b = addon:GetPercentColor(got/need)
			else
				Color2 = db.colors.ObjectiveColor
			end
			if db.questlog.showlevels then
				title = "["..level..self:GetQuestTag(tag, daily, group).."] "..title	
			end
			tooltip:AddDoubleLine(title, got..'/'..need, Color.r, Color.g, Color.b, Color2.r, Color2.g, Color2.b)
		end
	end
end

function addon:OnTooltipSetItem(tooltip, ...)
	local t = tooltip:GetItem()
	local Color = {}
	local Color2 = {}
	--addon:Debug("OnTooltipSetItem:"..tostring(t))
	if t then
		local uid, objective, got, need = Quixote:IsQuestItem(t)
		if uid then
			local _, _, title, level, tag, _, _, group, daily = Quixote:GetQuestByUid(uid)
			if db.colors.QuestColorLevels then
				Color = GetDifficultyColor(level)
			else
				Color = db.colors.tooltipquest
			end
			if db.colors.objfade then
				Color2.r, Color2.g, Color2.b = addon:GetPercentColor(got/need)
			else
				Color2 = db.colors.ObjectiveColor
			end
			if db.questlog.showlevels then
				title = "["..level..self:GetQuestTag(tag, daily, group).."] "..title	
			end
			tooltip:AddDoubleLine(title, got..'/'..need, Color.r, Color.g, Color.b, Color2.r, Color2.g, Color2.b)
		end
	end
end

function addon:TrackerClick()
		if QuestWatchFrame.ismoving then
			return
		end
		if (not dbpc.CurrentHoveredQuest or dbpc.CurrentHoveredQuest <= 0) then
			return
		end
		if arg1 == "LeftButton" and  db.tooltip.activetrackerleft then
			if not IsShiftKeyDown() and IsControlKeyDown()  then
				if ChatFrameEditBox:IsVisible() then
					keql:AddQuestStatusToChatFrame(dbpc.CurrentHoveredQuest)
				end				
			else
				Quixote:ShowQuestLog(dbpc.CurrentHoveredQuest)
				--SelectQuestLogEntry(dbpc.CurrentHoveredQuest)
				--if( not QuestLogFrame:IsVisible() ) then
					--ShowUIPanel(QuestLogFrame)
				--else
					--QuestLog_Update()
					--QuestLog_UpdateQuestDetails(1)
				--end
				if dbpc.minimized then 
					addon:Maximize() 
				end
			end
		elseif arg1 == "RightButton" and db.tooltip.activetrackerright then
			if dbpc.tooltipset then
				ResetCursor()
				GameTooltip:FadeOut()
				dbpc.tooltipset = false		
			end
			Quixote:RemoveQuestWatchByUid(dbpc.CurrentHoveredQuest)
			--RemoveQuestWatch()
			QuestLog_Update()		
			QuestWatch_Update()
		end	
end

function addon:TrackerTooltip()
		if not MouseIsOver(this) or (GetMouseFocus() ~= QuestWatchFrame) then
			return
		end
		local qid = 0
		local textline = 0
		local watchLine
		local x, y = GetCursorPosition()
		local s = QuestWatchFrame:GetEffectiveScale()
		x,y = x/s, y/s
	
		for i=1, MAX_QUESTWATCH_LINES, 1 do
			textline = textline + 1
			watchLine = getglobal("QuestWatchLine"..i)
			if ( watchLine:IsVisible() ) then
				local l, r, t, b = watchLine:GetLeft(), watchLine:GetRight(), watchLine:GetTop(), watchLine:GetBottom()
				if ( x <= r and x >= l and y <= t and y >= b ) then
					break;
				end
			end
		end
		if dbpc.TrackerQuests[textline] then
			ResetCursor()
			uid = dbpc.TrackerQuests[textline]
			local _, questObjectives = Quixote:GetQuestText(uid)
			dbpc.CurrentHoveredQuest = uid
			--local qTitle,qLvl,qTag,qRec,qStat,qObj,qZone,qID = Quixote:GetQuestByUid(uid)
			--q.unique_id, q.id, q.title, q.level, q.tag, GetNumQuestLeaderBoards(q.id), q.complete, q.group, q.daily, q.zone
			local _, qid, title, level = Quixote:GetQuestByUid(uid)
			
			if db.tooltip.activetracker then
				ShowInspectCursor()	
				GameTooltip:SetOwner(QuestWatchFrame, "ANCHOR_CURSOR")
				if db.colors.QuestColorLevels then
					Color = GetDifficultyColor(level)
				else
					Color = db.colors.tooltipquest
				end
				GameTooltip:AddLine(title,Color.r,Color.g,Color.b)
				if db.tooltip.activetrackerdesc then
					GameTooltip:AddLine(questObjectives,db.colors.tooltiptext.r,db.colors.tooltiptext.g,db.colors.tooltiptext.b,1)		
				end
				GameTooltip:Show()
				dbpc.tooltipset = true		
			end
		else
			dbpc.CurrentHoveredQuest = nil
			if dbpc.tooltipset then
				ResetCursor()
				GameTooltip:FadeOut()
				dbpc.tooltipset = false
			end		
		end
end
